# Get Started with AIGVE

<div class="grid cards" markdown>

-   :octicons-info-24:{ .middle } __About us__

    ---
    Get more information about `AIGVE` and use it in your function learning projects.

    [:octicons-arrow-right-24: More Information](../guides/about_us.md)

-   :fontawesome-solid-gear:{ .middle } __Installation__

    ---

    Install `AIGVE` with `pip` and set up the dependency in just minutes.

    [:octicons-arrow-right-24: How to Install](../guides/installation.md)

-   :material-clock-fast:{ .lg .middle } __Quickstart__

    ---

    A quickstart tutorial to help you use `AIGVE` APIs for {{our}} model training.

    [:octicons-arrow-right-24: Get Started](../guides/quick_start.md)


</div>